#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-gdk
version:                3.0.29
visibility:             public
id:                     gi-gdk-3.0.29-I08lUatRy452BCJi581bVX
key:                    gi-gdk-3.0.29-I08lUatRy452BCJi581bVX
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               Gdk bindings
description:            Bindings for Gdk, autogenerated by haskell-gi.
category:               Bindings
abi:                    c23c1644c5fdabccc3adb50d03102da9
exposed:                True
exposed-modules:
    GI.Gdk GI.Gdk.Callbacks GI.Gdk.Config GI.Gdk.Constants GI.Gdk.Enums
    GI.Gdk.Flags GI.Gdk.Functions GI.Gdk.Interfaces
    GI.Gdk.Interfaces.DevicePad GI.Gdk.Objects
    GI.Gdk.Objects.AppLaunchContext GI.Gdk.Objects.Cursor
    GI.Gdk.Objects.Device GI.Gdk.Objects.DeviceManager
    GI.Gdk.Objects.DeviceTool GI.Gdk.Objects.Display
    GI.Gdk.Objects.DisplayManager GI.Gdk.Objects.DragContext
    GI.Gdk.Objects.DrawingContext GI.Gdk.Objects.FrameClock
    GI.Gdk.Objects.GLContext GI.Gdk.Objects.Keymap
    GI.Gdk.Objects.Monitor GI.Gdk.Objects.Screen GI.Gdk.Objects.Seat
    GI.Gdk.Objects.Visual GI.Gdk.Objects.Window GI.Gdk.Structs
    GI.Gdk.Structs.Atom GI.Gdk.Structs.Color GI.Gdk.Structs.EventAny
    GI.Gdk.Structs.EventButton GI.Gdk.Structs.EventConfigure
    GI.Gdk.Structs.EventCrossing GI.Gdk.Structs.EventDND
    GI.Gdk.Structs.EventExpose GI.Gdk.Structs.EventFocus
    GI.Gdk.Structs.EventGrabBroken GI.Gdk.Structs.EventKey
    GI.Gdk.Structs.EventMotion GI.Gdk.Structs.EventOwnerChange
    GI.Gdk.Structs.EventPadAxis GI.Gdk.Structs.EventPadButton
    GI.Gdk.Structs.EventPadGroupMode GI.Gdk.Structs.EventProperty
    GI.Gdk.Structs.EventProximity GI.Gdk.Structs.EventScroll
    GI.Gdk.Structs.EventSelection GI.Gdk.Structs.EventSequence
    GI.Gdk.Structs.EventSetting GI.Gdk.Structs.EventTouch
    GI.Gdk.Structs.EventTouchpadPinch GI.Gdk.Structs.EventTouchpadSwipe
    GI.Gdk.Structs.EventVisibility GI.Gdk.Structs.EventWindowState
    GI.Gdk.Structs.FrameTimings GI.Gdk.Structs.Geometry
    GI.Gdk.Structs.KeymapKey GI.Gdk.Structs.Point GI.Gdk.Structs.RGBA
    GI.Gdk.Structs.Rectangle GI.Gdk.Structs.TimeCoord
    GI.Gdk.Structs.WindowAttr GI.Gdk.Structs.WindowRedirect
    GI.Gdk.Unions GI.Gdk.Unions.Event

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-gdk-3.0.29
library-dirs:           /usr/lib/ghc-9.6.6/site-local/gi-gdk-3.0.29 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/gi-gdk-3.0.29 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-gdk3
hs-libraries:           HSgi-gdk-3.0.29-I08lUatRy452BCJi581bVX
extra-libraries:
    gdk-3 pangocairo-1.0 pango-1.0 harfbuzz gdk_pixbuf-2.0
    cairo-gobject cairo gobject-2.0 glib-2.0 z

extra-libraries-static:
    gdk-3 pangocairo-1.0 m pangoft2-1.0 m pango-1.0 m thai datrie Xft
    harfbuzz-gobject harfbuzz m graphite2 gdk_pixbuf-2.0 m glycin-2
    seccomp lcms2 m pthread cairo-gobject dl Xi Xrandr Xcursor
    Xcomposite Xdamage Xfixes Xinerama xkbcommon wayland-cursor
    wayland-egl wayland-client m rt cairo m dl fontconfig m expat m
    freetype dl bz2 png16 m m brotlidec brotlicommon Xext Xrender
    xcb-render xcb-shm pixman-1 m epoxy dl X11 pthread xcb Xau Xdmcp GL
    EGL cloudproviders gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    atomic m pcre2-8 pthread z mount blkid systemd sysprof-capture-4
    fribidi

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/harfbuzz /usr/include/gdk-pixbuf-2.0
    /usr/include/glycin-2 /usr/include/cairo /usr/include/freetype2
    /usr/include/libpng16 /usr/include/pixman-1
    /usr/include/cloudproviders /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6
    /usr/include/fribidi

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-cairo-1.0.30-CdhA3dHcexX9NLxtFDkk7U
    gi-gdkpixbuf-2.0.32-6VpsopJllQEDFy4rT0mFKJ
    gi-gio-2.0.38-5KzGId26rq97IOkCofahsa
    gi-glib-2.0.30-IZ7yrYRIovZLNQrNPDpTka
    gi-gobject-2.0.31-5caYc4eDWhv1J5XUGThoCb
    gi-pango-1.0.30-6MLyLQC1i4g8CgTeSwmQYQ
    haskell-gi-0.26.17-LYG2jCmIKV42urp9p1RczH
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-gdk3/html/gi-gdk.haddock
haddock-html:           /usr/share/doc/haskell-gi-gdk3/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

